@@ -174,7 +174,7 @@ class RequestProcessor:
                 ("Accept-Encoding", "gzip, deflate"),
                 ("Accept", "*/*"),
                 ("Content-Length", "0"),
-                ("User-Agent", "python-asks/2.4.8"),
+                ("User-Agent", "python-asks/2.4.10"),
             ]
         )
 
@@ -240,10 +240,15 @@ class RequestProcessor:
                 self.scheme == self.initial_scheme and self.host == self.initial_netloc
             ):
                 self.sock._active = False
+                await self.sock.close()
 
         if self.streaming:
             return None, response_obj
 
+        if asks_headers.get('connection', '') == 'close' and self.sock._active:
+            await self.sock.close()
+            return None, response_obj
+
         return self.sock, response_obj
 
     async def _request_io(self, h11_request, h11_body, h11_connection):
@@ -575,7 +580,7 @@ class RequestProcessor:
                     for name, value in response.headers
                 ]
             ),
-            "body": b"",
+            "body": bytearray(),
             "url": self.req_url,
         }
 
